# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.api.ansible_collections_api import AnsibleCollectionsApi  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException


class TestAnsibleCollectionsApi(unittest.TestCase):
    """AnsibleCollectionsApi unit test stubs"""

    def setUp(self):
        self.api = pulpcore.client.pulp_ansible.api.ansible_collections_api.AnsibleCollectionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_role(self):
        """Test case for add_role

        """
        pass

    def test_list(self):
        """Test case for list

        List collections  # noqa: E501
        """
        pass

    def test_list_roles(self):
        """Test case for list_roles

        """
        pass

    def test_my_permissions(self):
        """Test case for my_permissions

        """
        pass

    def test_remove_role(self):
        """Test case for remove_role

        """
        pass

    def test_upload_collection(self):
        """Test case for upload_collection

        Upload a collection  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
