# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_namespace_metadata_response_list import PaginatedansibleAnsibleNamespaceMetadataResponseList  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestPaginatedansibleAnsibleNamespaceMetadataResponseList(unittest.TestCase):
    """PaginatedansibleAnsibleNamespaceMetadataResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedansibleAnsibleNamespaceMetadataResponseList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.paginatedansible_ansible_namespace_metadata_response_list.PaginatedansibleAnsibleNamespaceMetadataResponseList()  # noqa: E501
        if include_optional :
            return PaginatedansibleAnsibleNamespaceMetadataResponseList(
                count = 123, 
                next = 'http://api.example.org/accounts/?offset=400&limit=100', 
                previous = 'http://api.example.org/accounts/?offset=200&limit=100', 
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/ansible_namespace_metadata_response.ansible.AnsibleNamespaceMetadataResponse(
                        pulp_href = '0', 
                        name = 'a', 
                        company = '0', 
                        email = '0', 
                        description = '0', 
                        resources = '0', 
                        links = [
                            pulpcore.client.pulp_ansible.models.namespace_link_response.NamespaceLinkResponse(
                                url = '0', 
                                name = '0', )
                            ], 
                        avatar_sha256 = '0', 
                        avatar_url = '0', 
                        metadata_sha256 = '0', )
                    ]
            )
        else :
            return PaginatedansibleAnsibleNamespaceMetadataResponseList(
        )

    def testPaginatedansibleAnsibleNamespaceMetadataResponseList(self):
        """Test PaginatedansibleAnsibleNamespaceMetadataResponseList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
