# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.collection_version_search_list import CollectionVersionSearchList  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestCollectionVersionSearchList(unittest.TestCase):
    """CollectionVersionSearchList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CollectionVersionSearchList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.collection_version_search_list.CollectionVersionSearchList()  # noqa: E501
        if include_optional :
            return CollectionVersionSearchList(
                repository = pulpcore.client.pulp_ansible.models.repository.Repository(
                    pulp_labels = {
                        'key' : '0'
                        }, 
                    name = '0', 
                    description = '0', 
                    retain_repo_versions = 1, 
                    remote = '0', ), 
                collection_version = None, 
                namespace_metadata = null, 
                is_highest = True, 
                is_deprecated = True, 
                is_signed = True
            )
        else :
            return CollectionVersionSearchList(
                repository = pulpcore.client.pulp_ansible.models.repository.Repository(
                    pulp_labels = {
                        'key' : '0'
                        }, 
                    name = '0', 
                    description = '0', 
                    retain_repo_versions = 1, 
                    remote = '0', ),
                collection_version = None,
                namespace_metadata = null,
                is_highest = True,
                is_deprecated = True,
                is_signed = True,
        )

    def testCollectionVersionSearchList(self):
        """Test CollectionVersionSearchList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
